fn sole_base_value_effect(nodes: &[SpellDescriptionNode]) -> Option<u8>Expand description
The single $sN a branch renders, if that is the only effect value it names.
fn sole_base_value_effect(nodes: &[SpellDescriptionNode]) -> Option<u8>The single $sN a branch renders, if that is the only effect value it names.